import { ChainId } from "../common/chainid.js";
import { parseUnits } from "@ethersproject/units";
import { BigNumber } from "@ethersproject/bignumber";
export var GasUtils;
(function (GasUtils) {
    const makeGwei = (n) => parseUnits(n, "gwei");
    const CHAIN_GAS_PARAMS = {
        [ChainId.ETH]: {
            maxPriorityFee: makeGwei("1.5"),
            bridgeGasLimit: BigNumber.from(100000)
        },
        [ChainId.BOBA]: {
            gasPrice: makeGwei("10"),
            approveGasLimit: BigNumber.from(60000),
        },
        [ChainId.ARBITRUM]: {
            gasPrice: makeGwei("1.5"),
            bridgeGasLimit: BigNumber.from(1500000),
        },
        [ChainId.AVALANCHE]: {
            maxFeePerGas: makeGwei("80"),
            maxPriorityFee: makeGwei("3"),
            bridgeGasLimit: BigNumber.from(800000),
            approveGasLimit: BigNumber.from(75000),
        },
        [ChainId.AURORA]: {
            gasPrice: makeGwei('1'),
        },
    };
    GasUtils.makeGasParams = (chainId) => CHAIN_GAS_PARAMS[chainId] ?? {};
    GasUtils.populateGasParams = (chainId, txn, gasLimitKind) => Promise.resolve(txn)
        .then((tx) => {
        let { maxFeePerGas, maxPriorityFee, gasPrice, approveGasLimit, bridgeGasLimit } = GasUtils.makeGasParams(chainId);
        if (maxFeePerGas || gasPrice) {
            if (maxFeePerGas) {
                tx.maxFeePerGas = maxFeePerGas;
            }
            else if (gasPrice) {
                tx.gasPrice = gasPrice;
            }
        }
        if (maxPriorityFee)
            tx.maxPriorityFeePerGas = maxPriorityFee;
        switch (gasLimitKind) {
            case "bridge":
                if (bridgeGasLimit)
                    tx.gasLimit = bridgeGasLimit;
                break;
            case "approve":
                if (approveGasLimit)
                    tx.gasLimit = approveGasLimit;
                break;
        }
        return tx;
    });
})(GasUtils || (GasUtils = {}));
