import { SynapseBridgeFactory, L1BridgeZapFactory, L2BridgeZapFactory, BridgeConfigV3Factory, } from "./contracts.js";
import { ChainId } from "./common/chainid.js";
import { contractAddressFor } from "./common/utils.js";
import { rpcProviderForChain } from "./internal/rpcproviders.js";
export const newSynapseBridgeInstance = (params) => SynapseBridgeFactory.connect(params.address, params.signerOrProvider);
export const newL1BridgeZapInstance = (params) => L1BridgeZapFactory.connect(params.address, params.signerOrProvider);
export const newL2BridgeZapInstance = (params) => L2BridgeZapFactory.connect(params.address, params.signerOrProvider);
export var SynapseEntities;
(function (SynapseEntities) {
    const bridgeConfigV3Address = "0x3ee02f08B801B1990AC844d8CD2F119BA6Fb9bcF";
    SynapseEntities.synapseBridge = (params) => newSynapseBridgeInstance({
        address: contractAddressFor(params.chainId, "bridge"),
        ...params
    });
    SynapseEntities.l1BridgeZap = (params) => newL1BridgeZapInstance({
        address: contractAddressFor(params.chainId, "bridge_zap"),
        ...params
    });
    SynapseEntities.l2BridgeZap = (params) => newL2BridgeZapInstance({
        address: contractAddressFor(params.chainId, "bridge_zap"),
        ...params
    });
    SynapseEntities.zapBridge = (params) => params.chainId === ChainId.ETH
        ? SynapseEntities.l1BridgeZap(params)
        : SynapseEntities.l2BridgeZap(params);
    SynapseEntities.bridgeConfigV3 = () => BridgeConfigV3Factory.connect(bridgeConfigV3Address, rpcProviderForChain(ChainId.ETH));
})(SynapseEntities || (SynapseEntities = {}));
